@@ -1,5 +1,7 @@
 from abc import ABC
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple, Union
+
+from panoramic.cli.field.client import Aggregation
 
 
 class Actionable(ABC):
@@ -56,6 +58,101 @@ class PanoModelField:
         return self.to_dict() == o.to_dict()
 
 
+class PanoField(Actionable):
+    """Field definition."""
+
+    API_VERSION = 'v1'
+
+    def __init__(
+        self,
+        *,
+        slug: str,
+        group: str,
+        display_name: str,
+        data_type: str,
+        field_type: str,
+        description: Optional[str],
+        data_source: Optional[str],
+        calculation: Optional[str],
+        display_format: Optional[str],
+        aggregation: Optional[Aggregation],
+        package: Optional[str] = None,
+        file_name: Optional[str] = None,
+    ):
+        self.slug = slug
+        self.group = group
+        self.display_name = display_name
+        self.data_type = data_type
+        self.field_type = field_type
+        self.description = description
+        self.data_source = data_source
+        self.calculation = calculation
+        self.display_format = display_format
+        self.aggregation = aggregation
+        self.package = package
+        self.file_name = file_name
+
+    def to_dict(self) -> Dict[str, Any]:
+        # data_source is not persisted to YAML
+        return {k: v for k, v in self._to_internal_dict().items() if k != 'data_source'}
+
+    def _to_internal_dict(self) -> Dict[str, Any]:
+        data: Dict[str, Any] = {
+            'api_version': self.API_VERSION,
+            'slug': self.slug,
+            'group': self.group,
+            'display_name': self.display_name,
+            'data_type': self.data_type,
+            'field_type': self.field_type,
+            'data_source': self.data_source,
+        }
+
+        if self.description is not None:
+            data['description'] = self.description
+        if self.calculation is not None:
+            data['calculation'] = self.calculation
+        if self.aggregation is not None:
+            data['aggregation'] = self.aggregation.to_dict()
+        if self.display_format is not None:
+            data['display_format'] = self.display_format
+
+        return data
+
+    @classmethod
+    def from_dict(cls, inputs: Dict[str, Any]) -> 'PanoField':
+        aggregation = inputs.get('aggregation')
+        return cls(
+            slug=inputs['slug'],
+            group=inputs['group'],
+            display_name=inputs['display_name'],
+            data_type=inputs['data_type'],
+            field_type=inputs['field_type'],
+            description=inputs.get('description'),
+            data_source=inputs.get('data_source'),
+            aggregation=Aggregation.from_dict(aggregation) if aggregation is not None else None,
+            calculation=inputs.get('calculation'),
+            display_format=inputs.get('display_format'),
+            package=inputs.get('package'),
+            file_name=inputs.get('file_name'),
+        )
+
+    @property
+    def id(self) -> Union[Tuple[str], Tuple[str, str]]:
+        if self.data_source is not None:
+            return (self.data_source, self.slug)
+        else:
+            return (self.slug,)
+
+    def __hash__(self) -> int:
+        return hash(self.id)
+
+    def __eq__(self, o: object) -> bool:
+        if not isinstance(o, PanoField):
+            return False
+
+        return self._to_internal_dict() == o._to_internal_dict()
+
+
 class PanoModelJoin:
     """Represent joins on other models."""
 
@@ -185,8 +282,8 @@ class PanoVirtualDataSource(Actionable):
         self.package = package
 
     @property
-    def id(self) -> str:
-        return self.dataset_slug
+    def id(self) -> Tuple[str]:
+        return (self.dataset_slug,)
 
     def to_dict(self) -> Dict[str, Any]:
         return {
